require 'fastlane/action'
require 'json'
require 'fastlane_core/ui/ui'

module Fastlane
  module Helper
    class IosCdHelper
      # Check if a parameter is set or not
      def self.is_set(variable)
        str_variable = variable
        str_variable = variable.strip if variable.class.to_s == "String"
        variable && !(str_variable.nil? || str_variable.empty?)
      end

      # Decrypts ios credentials
      def self.decrypt_ios_keys(ios_directory)
        # Define the GPG command with options
        gpg_command = "gpg --quiet --batch --yes --decrypt --passphrase=#{ENV['IOS_KEYS_SECRET_PASSPHRASE']} \
          --output #{ios_directory}/ios_keys.zip #{ios_directory}/ios_keys.zip.gpg"

        # Execute the GPG command using system
        system(gpg_command)

        # Check if the command executed successfully
        if $?.success?
          # Move the extracted files to the current directory
          `jar xvf #{ios_directory}/ios_keys.zip && mv #{ios_directory}/ios_keys/* #{ios_directory}`
        else
          UI.user_error!("❌ Erreur lors de la décompression du fichier GPG")
        end
      end

      # Parse credential file
      def self.parse_ios_credentials(ios_directory)
        if File.exist?("#{ios_directory}/ios_credentials.json")
          # Read file and decrypt it
          file = File.read("#{ios_directory}/ios_credentials.json")
          JSON.parse(file)

        else
          UI.user_error!("❌ Ios credentials doesn't exist")
          puts("json file doesn't exist")
        end
      end

      # Check json fields
      def self.check_required_fields(required_fields, json)
        missing_fields = required_fields - json

        unless missing_fields.empty?
          raise ArgumentError, "❌ missing keys in credential json file : #{missing_fields}"
        end
      end

      # Check if set of environment variables are defined
      def self.check_environment_variables(variables)
        variables.each do |variable|
          unless ENV.key?(variable)
            raise "❌ The environment variable '#{variable}' is not defined."
          end
        end
      end

      # Delete built files
      def self.delete_artifacts(artifacts)
        artifacts.each do |file|
          File.delete(file) if File.exist?(file)
        end
      end
    end
  end
end
